/*
** iplog_scan.h - iplog scan/flood detector data.
** Copyright (C) 1999-2000 Ryan McCabe <odin@numb.org>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License, version 2,
** as published by the Free Software Foundation.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
**
** $Id: iplog_scan.h,v 1.11 2000/02/09 07:19:56 odin Exp $
*/

#ifndef __IPLOG_SCAN_H
#define __IPLOG_SCAN_H

#define SCAN_PORT		0
#define SCAN_NULL		1
#define SCAN_FIN		2
#define SCAN_XMAS		3
#define SCAN_UDP		4
#define SCAN_SMURF		5
#define SCAN_PING		6
#define SCAN_TOTAL		7

/* You may want to tune the following definitions. */

/*
** Size of the scan table when promisc mode is enabled.
** This must be a power of 2
*/
#define SCAN_TSIZE_P	256

/*
** Size of the scan table when promisc mode is not enabled.
** This must be a power of 2
*/
#define SCAN_TSIZE_N	128

/* Maximum number of entries for each hash. */
#define SCAN_MAXENT		4

#define PS_THOLD		15
#define NS_THOLD		10
#define FS_THOLD		10
#define XS_THOLD		10
#define UDP_THOLD		15
#define SMURF_THOLD		25
#define PING_THOLD		15

#define PS_TIMEOUT		50
#define NS_TIMEOUT		50
#define FS_TIMEOUT		50
#define XS_TIMEOUT		50
#define UDP_TIMEOUT		50
#define SMURF_TIMEOUT	50
#define PING_TIMEOUT	50

struct scan_data {
	struct scan_data *next;
	addr_t src_addr;
	addr_t dst_addr;
	time_t last;
	struct scan_t {
		u_short count;
		bool logged;
		time_t expire;
		u_long bytes;
	} type[SCAN_TOTAL];
};

struct scan_list {
	struct scan_data *head;
	pthread_mutex_t lock;
	u_long cnt;
};

struct scan_info {
	u_char *name;
	bool (*resolv)(void);
	u_long timeout;
	u_long threshold;
};

bool check_scan(u_char, const struct ip *ip, u_long);
void destroy_scan_table(void);
void expire_scans(void);
void init_scan_table(size_t tsize);

#endif /* ! __IPLOG_SCAN_H */
